pub struct ExtensionRouteBuilder {
pub global: Option<Box<OpenApiRouter<State>>>,
pub api_admin: Option<Box<OpenApiRouter<State>>>,
pub api_auth: Option<Box<OpenApiRouter<State>>>,
pub api_client: Option<Box<OpenApiRouter<State>>>,
pub api_client_servers_server: Option<Box<OpenApiRouter<State>>>,
pub api_remote: Option<Box<OpenApiRouter<State>>>,
pub api_remote_servers_server: Option<Box<OpenApiRouter<State>>>,
/* private fields */
}Fields
global: Option<Box<OpenApiRouter<State>>>api_admin: Option<Box<OpenApiRouter<State>>>api_auth: Option<Box<OpenApiRouter<State>>>api_client: Option<Box<OpenApiRouter<State>>>api_client_servers_server: Option<Box<OpenApiRouter<State>>>api_remote: Option<Box<OpenApiRouter<State>>>api_remote_servers_server: Option<Box<OpenApiRouter<State>>>Implementations
Sourceimpl ExtensionRouteBuilder
impl ExtensionRouteBuilder
pub fn new(state: State) -> Self
Sourcepub fn add_global_router(
self,
router: impl FnOnce(OpenApiRouter<State>) -> OpenApiRouter<State>,
) -> Self
pub fn add_global_router( self, router: impl FnOnce(OpenApiRouter<State>) -> OpenApiRouter<State>, ) -> Self
Adds a router for handling requests to /.
Sourcepub fn add_admin_api_router(
self,
router: impl FnOnce(OpenApiRouter<State>) -> OpenApiRouter<State>,
) -> Self
pub fn add_admin_api_router( self, router: impl FnOnce(OpenApiRouter<State>) -> OpenApiRouter<State>, ) -> Self
Adds a router for handling requests to /api/admin.
Authentication middleware is already handled by the parent router.
Sourcepub fn add_auth_api_router(
self,
router: impl FnOnce(OpenApiRouter<State>) -> OpenApiRouter<State>,
) -> Self
pub fn add_auth_api_router( self, router: impl FnOnce(OpenApiRouter<State>) -> OpenApiRouter<State>, ) -> Self
Adds a router for handling requests to /api/auth.
Sourcepub fn add_client_api_router(
self,
router: impl FnOnce(OpenApiRouter<State>) -> OpenApiRouter<State>,
) -> Self
pub fn add_client_api_router( self, router: impl FnOnce(OpenApiRouter<State>) -> OpenApiRouter<State>, ) -> Self
Adds a router for handling requests to /api/client.
Authentication middleware is already handled by the parent router.
Sourcepub fn add_client_server_api_router(
self,
router: impl FnOnce(OpenApiRouter<State>) -> OpenApiRouter<State>,
) -> Self
pub fn add_client_server_api_router( self, router: impl FnOnce(OpenApiRouter<State>) -> OpenApiRouter<State>, ) -> Self
Adds a router for handling requests to /api/client/servers/{server}.
Authentication middleware is already handled by the parent router.
Sourcepub fn add_remote_api_router(
self,
router: impl FnOnce(OpenApiRouter<State>) -> OpenApiRouter<State>,
) -> Self
pub fn add_remote_api_router( self, router: impl FnOnce(OpenApiRouter<State>) -> OpenApiRouter<State>, ) -> Self
Adds a router for handling requests to /api/remote.
Authentication middleware is already handled by the parent router.
Sourcepub fn add_remote_server_api_router(
self,
router: impl FnOnce(OpenApiRouter<State>) -> OpenApiRouter<State>,
) -> Self
pub fn add_remote_server_api_router( self, router: impl FnOnce(OpenApiRouter<State>) -> OpenApiRouter<State>, ) -> Self
Adds a router for handling requests to /api/admin.
Authentication middleware is already handled by the parent router.